Crate ra4m1_fsp_pac

Crate ra4m1_fsp_pac 

Peripheral access API for R7FA4M1AB microcontrollers (generated using svd2rust v0.37.1 ( ))

You can find an overview of the generated API here.

API features to be included in the next svd2rust release can be generated by cloning the svd2rust repository, checking out the above commit, and running cargo doc --open.

Re-exports

pub use self::dmac0 as dmac1;
pub use self::dmac0 as dmac2;
pub use self::dmac0 as dmac3;
pub use self::port1 as port2;
pub use self::port1 as port3;
pub use self::port1 as port4;
pub use self::port0 as port5;
pub use self::port0 as port6;
pub use self::port0 as port7;
pub use self::port0 as port8;
pub use self::port0 as port9;
pub use self::sci0 as sci1;
pub use self::sci2 as sci9;
pub use self::agt0 as agt1;
pub use self::gpt320 as gpt321;
pub use self::gpt162 as gpt163;
pub use self::gpt162 as gpt164;
pub use self::gpt162 as gpt165;
pub use self::gpt162 as gpt166;
pub use self::gpt162 as gpt167;
pub use self::Interrupt as interrupt;

Modules

acmplp
Low-Power Analog Comparator
adc140
14bit A/D Converter
agt0
Asynchronous General purpose Timer 0
bus
BUS Control
cac
Clock Frequency Accuracy Measurement Circuit
can0
CAN0 Module
crc
CRC Calculator
ctsu
Capacitive Touch Sensing Unit
dac8
8-bit D/A converter
dac12
12-bit D/A converter
dbg
Debug Function
dma
DMAC Module Activation
dmac0
Direct memory access controller 0
doc
Data Operation Circuit
dtc
Data Transfer Controller
elc
Event Link Controller
fcache
Flash Cache
generic
Common register and bit access and modify traits
gpt162
General PWM Timer 2 (16-bit)
gpt320
General PWM Timer 0 (32-bit)
gpt_ops
Output Phase Switching Controller
icu
Interrupt Controller
iic0
Inter-Integrated Circuit 0
iic1
Inter-Integrated Circuit 1
iwdt
Independent Watchdog Timer
kint
Key Interrupt Function
mmpu
Bus Master MPU
mstp
Module Stop Control B,C,D
opamp
OperationalAmplifier
pfs
Pmn Pin Function Control Register
pmisc
Miscellaneous Port Control Register
poeg
Port Output Enable Module for GPT
port0
Port 0 Control Registers
port1
Port 1 Control Registers
rtc
Realtime Clock
sci0
Serial Communication Interface 0
sci2
Serial Communication Interface 2
slcdc
Segment LCD Controller/Driver
smpu
Bus Slave MPU
spi0
Serial Peripheral Interface 0
spi1
Serial Peripheral Interface 1
spmon
CPU Stack Pointer Monitor
sram
SRAM Control
ssie0
Serial Sound Interface Ver.2.0
system
System Control
tsn
Temperature Sensor
usbfs
USB 2.0 FS Module
wdt
Watchdog Timer

Structs

InvalidInterruptNumber
Peripherals
All the peripherals.

Enums

Interrupt
Enumeration of all the interrupts.

Constants

NVIC_PRIO_BITS
Number available in the NVIC for configuring priority

Type Aliases

ACMPLP
Low-Power Analog Comparator
ADC140
14bit A/D Converter
AGT0
Asynchronous General purpose Timer 0
AGT1
Asynchronous General purpose Timer 1
BUS
BUS Control
CAC
Clock Frequency Accuracy Measurement Circuit
CAN0
CAN0 Module
CRC
CRC Calculator
CTSU
Capacitive Touch Sensing Unit
DAC8
8-bit D/A converter
DAC12
12-bit D/A converter
DBG
Debug Function
DMA
DMAC Module Activation
DMAC0
Direct memory access controller 0
DMAC1
Direct memory access controller 1
DMAC2
Direct memory access controller 2
DMAC3
Direct memory access controller 3
DOC
Data Operation Circuit
DTC
Data Transfer Controller
ELC
Event Link Controller
FCACHE
Flash Cache
GPT162
General PWM Timer 2 (16-bit)
GPT163
General PWM Timer 3 (16-bit)
GPT164
General PWM Timer 4 (16-bit)
GPT165
General PWM Timer 5 (16-bit)
GPT166
General PWM Timer 6 (16-bit)
GPT167
General PWM Timer 7 (16-bit)
GPT320
General PWM Timer 0 (32-bit)
GPT321
General PWM Timer 1 (32-bit)
GPT_OPS
Output Phase Switching Controller
ICU
Interrupt Controller
IIC0
Inter-Integrated Circuit 0
IIC1
Inter-Integrated Circuit 1
IWDT
Independent Watchdog Timer
KINT
Key Interrupt Function
MMPU
Bus Master MPU
MSTP
Module Stop Control B,C,D
OPAMP
OperationalAmplifier
PFS
Pmn Pin Function Control Register
PMISC
Miscellaneous Port Control Register
POEG
Port Output Enable Module for GPT
PORT0
Port 0 Control Registers
PORT1
Port 1 Control Registers
PORT2
Port 2 Control Registers
PORT3
Port 3 Control Registers
PORT4
Port 4 Control Registers
PORT5
Port 5 Control Registers
PORT6
Port 6 Control Registers
PORT7
Port 7 Control Registers
PORT8
Port 8 Control Registers
PORT9
Port 9 Control Registers
RTC
Realtime Clock
SCI0
Serial Communication Interface 0
SCI1
Serial Communication Interface 1
SCI2
Serial Communication Interface 2
SCI9
Serial Communication Interface 9
SLCDC
Segment LCD Controller/Driver
SMPU
Bus Slave MPU
SPI0
Serial Peripheral Interface 0
SPI1
Serial Peripheral Interface 1
SPMON
CPU Stack Pointer Monitor
SRAM
SRAM Control
SSIE0
Serial Sound Interface Ver.2.0
SYSTEM
System Control
TSN
Temperature Sensor
USBFS
USB 2.0 FS Module
WDT
Watchdog Timer